Documentation
¶
Index ¶
- func Register(scheme string, open func(*url.URL) (Store, error))
- type Agg
- type Counters
- func (c Counters) Add(ctx context.Context, at time.Time, delta uint64) error
- func (c Counters) Compact(ctx context.Context) error
- func (c Counters) Range(ctx context.Context, from, to time.Time, span time.Duration, agg Agg) (iter.Seq2[time.Time, float64], error)
- func (c Counters) Values(ctx context.Context, from, to time.Time) (iter.Seq2[time.Time, float64], error)
- type DB
- type Option
- type Samples
- func (s Samples) Compact(ctx context.Context) error
- func (s Samples) Range(ctx context.Context, from, to time.Time, span time.Duration, agg Agg) (iter.Seq2[time.Time, float64], error)
- func (s Samples) Set(ctx context.Context, at time.Time, value float64) error
- func (s Samples) Values(ctx context.Context, from, to time.Time) (iter.Seq2[time.Time, float64], error)
- type Sketch
- type Sketches
- func (h Sketches) Add(ctx context.Context, at time.Time, value float64) error
- func (h Sketches) Compact(ctx context.Context) error
- func (h Sketches) Range(ctx context.Context, from, to time.Time, span time.Duration) (iter.Seq2[time.Time, Sketch], error)
- func (h Sketches) Values(ctx context.Context, from, to time.Time) (iter.Seq2[time.Time, Sketch], error)
- type Store
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Counters ¶
type Counters struct {
// contains filtered or unexported fields
}
Counters writes and reads grow-only counters.
type DB ¶
type DB struct {
// contains filtered or unexported fields
}
DB stores time-series samples, counters, and sketches.
type Option ¶
Option configures a DB.
func WithCompaction ¶
WithCompaction enables lossy compaction of raw values older than after.
func WithCompactor ¶
WithCompactor starts a jittered background compactor for keys seen locally.
func WithFlushEvery ¶
WithFlushEvery buffers writes in memory and flushes them periodically.
type Samples ¶
type Samples struct {
// contains filtered or unexported fields
}
Samples writes and reads float64 samples.
func (Samples) Range ¶
func (s Samples) Range(ctx context.Context, from, to time.Time, span time.Duration, agg Agg) (iter.Seq2[time.Time, float64], error)
Range returns bucketed aggregate values.
type Sketch ¶ added in v0.2.0
type Sketch struct {
// contains filtered or unexported fields
}
Sketch is an immutable encoded distribution.
type Sketches ¶ added in v0.2.0
type Sketches struct {
// contains filtered or unexported fields
}
Sketches writes and reads distributions of float64 observations.
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
Package machine identifies the current process for replica tags.
|
Package machine identifies the current process for replica tags. |
|
storage
|
|
|
cached
Package cached adds a read-through cache to a store.
|
Package cached adds a read-through cache to a store. |
|
memory
module
|
|
|
sqlite
module
|
Click to show internal directories.
Click to hide internal directories.